
## Release notes


### Version 0.0.9, 08-2022
- Bugfix for AGAIN missing/false MANIFEST.in values

### Version 0.0.8, 08-2022
- Bugfix for AGAIN missing/false MANIFEST.in values

### Version 0.0.7, 08-2022
- Bugfix for missing/false MANIFEST.in values

### Version 0.0.6, 08-2022
- auth_checks for authorized_client and host where included
- changes to joringels.yml file handling
- http string encryption was added

### Versions 0.0.2 to 0.0.5, 08-2022
- q2 bugfixes added


### Version 0.0.1, 06-2022
- python 3.9 - 3.10
- initial push